@@ -56,8 +56,8 @@
     </message>
     <message>
         <location filename="../addappdialog.ui" line="194"/>
-        <source>...</source>
-        <translation>...</translation>
+        <source>Select...</source>
+        <translation>Seleziona...</translation>
     </message>
     <message>
         <location filename="../addappdialog.ui" line="201"/>
@@ -121,6 +121,248 @@
         <translation>Salva</translation>
     </message>
 </context>
+<context>
+    <name>MainWindow</name>
+    <message>
+        <location filename="../mainwindow.ui" line="17"/>
+        <location filename="../mainwindow.cpp" line="839"/>
+        <source>MX Menu Editor</source>
+        <translation>MX Menu Editor</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="34"/>
+        <source>Advanced Editor</source>
+        <translation>Editor Avanzato</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="55"/>
+        <source>Categories and applications</source>
+        <translation>Categorie e applicazioni</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="82"/>
+        <source>Add custom application</source>
+        <translation>Aggiungi applicazione personale</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="96"/>
+        <source>Options</source>
+        <translation>Opzioni</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="105"/>
+        <source>Run in terminal</source>
+        <translation>Avvia da terminale</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="115"/>
+        <source>Hide</source>
+        <translation>Nascondi</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="125"/>
+        <source>Notify startup</source>
+        <translation>Notifica all&apos;avvio</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="148"/>
+        <source>Quick Editor</source>
+        <translation>Editor semplice e veloce</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="160"/>
+        <source>Comment:</source>
+        <translation>Commento:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="170"/>
+        <source>Restore original item</source>
+        <translation>Ripristina elemento originale</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="181"/>
+        <source>Command:</source>
+        <translation>Comando:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="191"/>
+        <source>Select...</source>
+        <translation>Seleziona...</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="205"/>
+        <source>Name:</source>
+        <translation>Nome:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="226"/>
+        <source>Icon</source>
+        <translation>Icona</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="266"/>
+        <location filename="../mainwindow.cpp" line="541"/>
+        <source>Change icon</source>
+        <translation>Cambia Icona</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="280"/>
+        <source>Categories</source>
+        <translation>Categorie</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="292"/>
+        <source>Add</source>
+        <translation>Aggiungi</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="306"/>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="372"/>
+        <source>Quit application</source>
+        <translation>Esci dall&apos;applicazione</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="375"/>
+        <source>Close</source>
+        <translation>Chiudi</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="382"/>
+        <source>Alt+N</source>
+        <translation>Alt+N</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="423"/>
+        <source>Display help</source>
+        <translation>Visualizza la guida</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="426"/>
+        <source>Help</source>
+        <translation>Aiuto</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="433"/>
+        <source>Alt+H</source>
+        <translation>Alt+H</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="452"/>
+        <source>Save Changes</source>
+        <translation>Salva Cambiamenti</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="459"/>
+        <source>Ctrl+S</source>
+        <translation>Ctrl+S</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="494"/>
+        <source>About this application</source>
+        <translation>Informazioni su questa applicazione</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="497"/>
+        <source>About...</source>
+        <translation>Info</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="504"/>
+        <source>Alt+B</source>
+        <translation>Alt+B</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="462"/>
+        <source>Select executable file</source>
+        <translation>Seleziona un file eseguibile</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="525"/>
+        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
+        <translation>File d&apos;immagine (*.png *.jpg *.bmp *.xpm)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="718"/>
+        <source>Choose category</source>
+        <translation>Scegli categoria</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="../mainwindow.cpp" line="845"/>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Cancel</source>
+        <translation>Annulla</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="730"/>
+        <source>OK</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="820"/>
+        <source>Error</source>
+        <translation>Errore</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="820"/>
+        <source>Could not save the file</source>
+        <translation>Non è possibile salvare il file:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="838"/>
+        <source>About MX Menu Editor</source>
+        <translation>Informazioni su MX Menu Editor</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="839"/>
+        <source>Version: </source>
+        <translation>Versione: </translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="840"/>
+        <source>Program for editing Xfce menu</source>
+        <translation>Programma per modificare il menu di Xfce</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="842"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation>Copyright (c) MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="843"/>
+        <source>License</source>
+        <translation>Licenza</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="844"/>
+        <source>Changelog</source>
+        <translation>Changelog</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="860"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Chiudi</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Save changes?</source>
+        <translation>Salvare i cambiamenti?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Do you want to save your edits?</source>
+        <translation>Vuoi salvare le tue modifiche?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Save</source>
+        <translation>Salva</translation>
+    </message>
+</context>
 <context>
     <name>QApplication</name>
     <message>
@@ -129,246 +371,4 @@
         <translation>Devi eseguire questo programma come normale utente.</translation>
     </message>
 </context>
-<context>
-    <name>mxmenueditor</name>
-    <message>
-        <location filename="../mxmenueditor.ui" line="17"/>
-        <location filename="../mxmenueditor.cpp" line="839"/>
-        <source>MX Menu Editor</source>
-        <translation>MX Menu Editor</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="34"/>
-        <source>Advanced Editor</source>
-        <translation>Editor Avanzato</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="55"/>
-        <source>Categories and applications</source>
-        <translation>Categorie e applicazioni</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="82"/>
-        <source>Add custom application</source>
-        <translation>Aggiungi applicazione personale</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="96"/>
-        <source>Options</source>
-        <translation>Opzioni</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="105"/>
-        <source>Run in terminal</source>
-        <translation>Avvia da terminale</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="115"/>
-        <source>Hide</source>
-        <translation>Nascondi</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="125"/>
-        <source>Notify startup</source>
-        <translation>Notifica all&apos;avvio</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="148"/>
-        <source>Quick Editor</source>
-        <translation>Editor semplice e veloce</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="160"/>
-        <source>Comment:</source>
-        <translation>Commento:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="170"/>
-        <source>Restore original item</source>
-        <translation>Ripristina elemento originale</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="181"/>
-        <source>Command:</source>
-        <translation>Comando:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="191"/>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="205"/>
-        <source>Name:</source>
-        <translation>Nome:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="226"/>
-        <source>Icon</source>
-        <translation>Icona</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="266"/>
-        <location filename="../mxmenueditor.cpp" line="541"/>
-        <source>Change icon</source>
-        <translation>Cambia Icona</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="280"/>
-        <source>Categories</source>
-        <translation>Categorie</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="292"/>
-        <source>Add</source>
-        <translation>Aggiungi</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="306"/>
-        <source>Delete</source>
-        <translation>Elimina</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="372"/>
-        <source>Quit application</source>
-        <translation> Chiudi l&apos;applicazione</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="375"/>
-        <source>Close</source>
-        <translation>Chiudi</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="382"/>
-        <source>Alt+N</source>
-        <translation>Alt+N</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="423"/>
-        <source>Display help</source>
-        <translation>Visualizza la guida</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="426"/>
-        <source>Help</source>
-        <translation>Aiuto</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="433"/>
-        <source>Alt+H</source>
-        <translation>Alt+H</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="452"/>
-        <source>Save Changes</source>
-        <translation>Salva Cambiamenti</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="459"/>
-        <source>Ctrl+S</source>
-        <translation>Ctrl+S</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="494"/>
-        <source>About this application</source>
-        <translation>Informazioni su questa applicazione</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="497"/>
-        <source>About...</source>
-        <translation>Info...</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="504"/>
-        <source>Alt+B</source>
-        <translation>Alt+B</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="462"/>
-        <source>Select executable file</source>
-        <translation>Seleziona un file eseguibile</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="525"/>
-        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
-        <translation>File d&apos;immagine (*.png *.jpg *.bmp *.xpm)</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="718"/>
-        <source>Choose category</source>
-        <translation>Scegli categoria</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="729"/>
-        <location filename="../mxmenueditor.cpp" line="845"/>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Cancel</source>
-        <translation>Annulla</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="730"/>
-        <source>OK</source>
-        <translation>Ok</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="820"/>
-        <source>Error</source>
-        <translation>Errore</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="820"/>
-        <source>Could not save the file</source>
-        <translation>Non è possibile salvare il file:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="838"/>
-        <source>About MX Menu Editor</source>
-        <translation>Informazioni su MX Menu Editor</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="839"/>
-        <source>Version: </source>
-        <translation>Versione:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="840"/>
-        <source>Program for editing Xfce menu</source>
-        <translation>Programma per modificare il menu di Xfce</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="842"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation>Copyright (c) MX Linux</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="843"/>
-        <source>License</source>
-        <translation>Licenza</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="844"/>
-        <source>Changelog</source>
-        <translation>Changelog</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="860"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Chiudi</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Save changes?</source>
-        <translation>Salvare i cambiamenti?</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Do you want to save your edits?</source>
-        <translation>Vuoi salvare le tue modifiche?</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Save</source>
-        <translation>Salva</translation>
-    </message>
-</context>
 </TS>
