@@ -56,8 +56,8 @@
     </message>
     <message>
         <location filename="../addappdialog.ui" line="194"/>
-        <source>...</source>
-        <translation>...</translation>
+        <source>Select...</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../addappdialog.ui" line="201"/>
@@ -121,6 +121,248 @@
         <translation>Salvar</translation>
     </message>
 </context>
+<context>
+    <name>MainWindow</name>
+    <message>
+        <location filename="../mainwindow.ui" line="17"/>
+        <location filename="../mainwindow.cpp" line="839"/>
+        <source>MX Menu Editor</source>
+        <translation>MX Editor do Menu Iniciar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="34"/>
+        <source>Advanced Editor</source>
+        <translation>Editor avançado</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="55"/>
+        <source>Categories and applications</source>
+        <translation>Categorias e aplicações</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="82"/>
+        <source>Add custom application</source>
+        <translation>Adicionar outra aplicação</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="96"/>
+        <source>Options</source>
+        <translation>Opções</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="105"/>
+        <source>Run in terminal</source>
+        <translation>Executar em Terminal</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="115"/>
+        <source>Hide</source>
+        <translation>Ocultar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="125"/>
+        <source>Notify startup</source>
+        <translation>Notificar ao iniciar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="148"/>
+        <source>Quick Editor</source>
+        <translation>Editor rápido</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="160"/>
+        <source>Comment:</source>
+        <translation>Comentário</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="170"/>
+        <source>Restore original item</source>
+        <translation>Restaurar o original</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="181"/>
+        <source>Command:</source>
+        <translation>Comando: </translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="191"/>
+        <source>Select...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="205"/>
+        <source>Name:</source>
+        <translation>Nome:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="226"/>
+        <source>Icon</source>
+        <translation>Ícone</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="266"/>
+        <location filename="../mainwindow.cpp" line="541"/>
+        <source>Change icon</source>
+        <translation>Mudar o ícone</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="280"/>
+        <source>Categories</source>
+        <translation>Categorias</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="292"/>
+        <source>Add</source>
+        <translation>Adicionar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="306"/>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="372"/>
+        <source>Quit application</source>
+        <translation>Sair da aplicação</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="375"/>
+        <source>Close</source>
+        <translation>Fechar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="382"/>
+        <source>Alt+N</source>
+        <translation>Alt+N</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="423"/>
+        <source>Display help</source>
+        <translation>Mostrar a ajuda</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="426"/>
+        <source>Help</source>
+        <translation>Ajuda</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="433"/>
+        <source>Alt+H</source>
+        <translation>Alt+H</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="452"/>
+        <source>Save Changes</source>
+        <translation>salvar alterações</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="459"/>
+        <source>Ctrl+S</source>
+        <translation>Ctrl+S</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="494"/>
+        <source>About this application</source>
+        <translation>Sobre esta aplicação</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="497"/>
+        <source>About...</source>
+        <translation>Sobre...</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="504"/>
+        <source>Alt+B</source>
+        <translation>Alt+B</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="462"/>
+        <source>Select executable file</source>
+        <translation>Seleccionar o arquivo executável</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="525"/>
+        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
+        <translation>arquivos de Imagem (*.png *.jpg *.bmp *.xpm)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="718"/>
+        <source>Choose category</source>
+        <translation>Escolher categoria</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="../mainwindow.cpp" line="845"/>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="730"/>
+        <source>OK</source>
+        <translation>Aceitar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="820"/>
+        <source>Error</source>
+        <translation>Erro</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="820"/>
+        <source>Could not save the file</source>
+        <translation>Não foi possível salvar o arquivo</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="838"/>
+        <source>About MX Menu Editor</source>
+        <translation>Sobre o MX-Editor do Menu Iniciar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="839"/>
+        <source>Version: </source>
+        <translation>Versão: </translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="840"/>
+        <source>Program for editing Xfce menu</source>
+        <translation>Programa para editar o menu do Xfce</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="842"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation>Direitos de Autor (c) MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="843"/>
+        <source>License</source>
+        <translation>Licença</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="844"/>
+        <source>Changelog</source>
+        <translation>Relatório de alterações</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="860"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Fechar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Save changes?</source>
+        <translation>Salvar alterações?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Do you want to save your edits?</source>
+        <translation>Pretende salvar as alterações?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Save</source>
+        <translation>Salvar</translation>
+    </message>
+</context>
 <context>
     <name>QApplication</name>
     <message>
@@ -129,246 +371,4 @@
         <translation>Tem que executar este programa como utilizador normal.</translation>
     </message>
 </context>
-<context>
-    <name>mxmenueditor</name>
-    <message>
-        <location filename="../mxmenueditor.ui" line="17"/>
-        <location filename="../mxmenueditor.cpp" line="839"/>
-        <source>MX Menu Editor</source>
-        <translation>MX Editor do Menu Iniciar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="34"/>
-        <source>Advanced Editor</source>
-        <translation>Editor avançado</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="55"/>
-        <source>Categories and applications</source>
-        <translation>Categorias e aplicações</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="82"/>
-        <source>Add custom application</source>
-        <translation>Adicionar outra aplicação</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="96"/>
-        <source>Options</source>
-        <translation>Opções</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="105"/>
-        <source>Run in terminal</source>
-        <translation>Executar em Terminal</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="115"/>
-        <source>Hide</source>
-        <translation>Ocultar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="125"/>
-        <source>Notify startup</source>
-        <translation>Notificar ao iniciar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="148"/>
-        <source>Quick Editor</source>
-        <translation>Editor rápido</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="160"/>
-        <source>Comment:</source>
-        <translation>Comentário</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="170"/>
-        <source>Restore original item</source>
-        <translation>Restaurar o original</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="181"/>
-        <source>Command:</source>
-        <translation>Comando:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="191"/>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="205"/>
-        <source>Name:</source>
-        <translation>Nome:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="226"/>
-        <source>Icon</source>
-        <translation>Ícone</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="266"/>
-        <location filename="../mxmenueditor.cpp" line="541"/>
-        <source>Change icon</source>
-        <translation>Mudar o ícone</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="280"/>
-        <source>Categories</source>
-        <translation>Categorias</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="292"/>
-        <source>Add</source>
-        <translation>Adicionar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="306"/>
-        <source>Delete</source>
-        <translation>Eliminar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="372"/>
-        <source>Quit application</source>
-        <translation>Sair da aplicação</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="375"/>
-        <source>Close</source>
-        <translation>Fechar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="382"/>
-        <source>Alt+N</source>
-        <translation>Alt+N</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="423"/>
-        <source>Display help</source>
-        <translation>Mostrar a ajuda</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="426"/>
-        <source>Help</source>
-        <translation>Ajuda</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="433"/>
-        <source>Alt+H</source>
-        <translation>Alt+H</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="452"/>
-        <source>Save Changes</source>
-        <translation>salvar alterações</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="459"/>
-        <source>Ctrl+S</source>
-        <translation>Ctrl+S</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="494"/>
-        <source>About this application</source>
-        <translation>Sobre esta aplicação</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="497"/>
-        <source>About...</source>
-        <translation>Sobre...</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="504"/>
-        <source>Alt+B</source>
-        <translation>Alt+B</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="462"/>
-        <source>Select executable file</source>
-        <translation>Seleccionar o arquivo executável</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="525"/>
-        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
-        <translation>arquivos de Imagem (*.png *.jpg *.bmp *.xpm)</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="718"/>
-        <source>Choose category</source>
-        <translation>Escolher categoria</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="729"/>
-        <location filename="../mxmenueditor.cpp" line="845"/>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Cancel</source>
-        <translation>Cancelar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="730"/>
-        <source>OK</source>
-        <translation>Aceitar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="820"/>
-        <source>Error</source>
-        <translation>Erro</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="820"/>
-        <source>Could not save the file</source>
-        <translation>Não foi possível salvar o arquivo</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="838"/>
-        <source>About MX Menu Editor</source>
-        <translation>Sobre o MX-Editor do Menu Iniciar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="839"/>
-        <source>Version: </source>
-        <translation>Versão:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="840"/>
-        <source>Program for editing Xfce menu</source>
-        <translation>Programa para editar o menu do Xfce</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="842"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation>Copyright (c) MX Linux</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="843"/>
-        <source>License</source>
-        <translation>Licença</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="844"/>
-        <source>Changelog</source>
-        <translation>Relatório de alterações</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="860"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Fechar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Save changes?</source>
-        <translation>salvar alterações?</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Do you want to save your edits?</source>
-        <translation>Pretende salvar as alterações?</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Save</source>
-        <translation>salvar</translation>
-    </message>
-</context>
 </TS>
