@@ -56,8 +56,8 @@
     </message>
     <message>
         <location filename="../addappdialog.ui" line="194"/>
-        <source>...</source>
-        <translation>...</translation>
+        <source>Select...</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../addappdialog.ui" line="201"/>
@@ -121,6 +121,248 @@
         <translation>Kaydet</translation>
     </message>
 </context>
+<context>
+    <name>MainWindow</name>
+    <message>
+        <location filename="../mainwindow.ui" line="17"/>
+        <location filename="../mainwindow.cpp" line="839"/>
+        <source>MX Menu Editor</source>
+        <translation>MX Menü Düzenleyici</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="34"/>
+        <source>Advanced Editor</source>
+        <translation>Gelişmiş Düzenleyici</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="55"/>
+        <source>Categories and applications</source>
+        <translation>Kategoriler ve uygulamalar</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="82"/>
+        <source>Add custom application</source>
+        <translation>Özel uygulama ekle</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="96"/>
+        <source>Options</source>
+        <translation>Seçenekler</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="105"/>
+        <source>Run in terminal</source>
+        <translation>Uçbirimde çalıştır</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="115"/>
+        <source>Hide</source>
+        <translation>Gizle</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="125"/>
+        <source>Notify startup</source>
+        <translation>Başlangıçta bildir</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="148"/>
+        <source>Quick Editor</source>
+        <translation>Çabuk düzenleyici</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="160"/>
+        <source>Comment:</source>
+        <translation>Yorum:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="170"/>
+        <source>Restore original item</source>
+        <translation>Özgün öğeyi geri yükle</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="181"/>
+        <source>Command:</source>
+        <translation>Komut:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="191"/>
+        <source>Select...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="205"/>
+        <source>Name:</source>
+        <translation>Ad:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="226"/>
+        <source>Icon</source>
+        <translation>Simge</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="266"/>
+        <location filename="../mainwindow.cpp" line="541"/>
+        <source>Change icon</source>
+        <translation>Simgeyi değiştir</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="280"/>
+        <source>Categories</source>
+        <translation>Kategoriler</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="292"/>
+        <source>Add</source>
+        <translation>Ekle</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="306"/>
+        <source>Delete</source>
+        <translation>Sil</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="372"/>
+        <source>Quit application</source>
+        <translation>Uygulamadan çık</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="375"/>
+        <source>Close</source>
+        <translation>Kapat</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="382"/>
+        <source>Alt+N</source>
+        <translation>Alt+N</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="423"/>
+        <source>Display help</source>
+        <translation>Yardımı görüntüle</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="426"/>
+        <source>Help</source>
+        <translation>Yardım</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="433"/>
+        <source>Alt+H</source>
+        <translation>Alt+H</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="452"/>
+        <source>Save Changes</source>
+        <translation>Değişiklikleri kaydet</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="459"/>
+        <source>Ctrl+S</source>
+        <translation>Ctrl+S</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="494"/>
+        <source>About this application</source>
+        <translation>Uygulama hakkında</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="497"/>
+        <source>About...</source>
+        <translation>Hakkında...</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="504"/>
+        <source>Alt+B</source>
+        <translation>Alt+B</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="462"/>
+        <source>Select executable file</source>
+        <translation>Çalıştırılabilir dosyayı seçin</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="525"/>
+        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
+        <translation>Resim Dosyaları  (*.png *.jpg *.bmp *.xpm)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="718"/>
+        <source>Choose category</source>
+        <translation>Kategori seçin</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="../mainwindow.cpp" line="845"/>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Cancel</source>
+        <translation>İptal</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="730"/>
+        <source>OK</source>
+        <translation>Tamam</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="820"/>
+        <source>Error</source>
+        <translation>Hata</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="820"/>
+        <source>Could not save the file</source>
+        <translation>Dosya kaydedilemedi</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="838"/>
+        <source>About MX Menu Editor</source>
+        <translation>MX Menü Düzenleyici Hakkında</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="839"/>
+        <source>Version: </source>
+        <translation>Sürüm</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="840"/>
+        <source>Program for editing Xfce menu</source>
+        <translation>Xfce menüsünü düzenleme programı</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="842"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation>Copyright (c) MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="843"/>
+        <source>License</source>
+        <translation>Ruhsat</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="844"/>
+        <source>Changelog</source>
+        <translation>Değişim günlüğü</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="860"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Kapat</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Save changes?</source>
+        <translation>Değişiklikler kaydedilsin mi?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Do you want to save your edits?</source>
+        <translation>Düzenlemelerinizi kaydetmek istiyor musunuz?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="906"/>
+        <source>Save</source>
+        <translation>Kaydet</translation>
+    </message>
+</context>
 <context>
     <name>QApplication</name>
     <message>
@@ -129,246 +371,4 @@
         <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
     </message>
 </context>
-<context>
-    <name>mxmenueditor</name>
-    <message>
-        <location filename="../mxmenueditor.ui" line="17"/>
-        <location filename="../mxmenueditor.cpp" line="839"/>
-        <source>MX Menu Editor</source>
-        <translation>MX Menü Düzenleyici</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="34"/>
-        <source>Advanced Editor</source>
-        <translation>Gelişmiş Düzenleyici</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="55"/>
-        <source>Categories and applications</source>
-        <translation>Kategoriler ve uygulamalar</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="82"/>
-        <source>Add custom application</source>
-        <translation>Özel uygulama ekle</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="96"/>
-        <source>Options</source>
-        <translation>Seçenekler</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="105"/>
-        <source>Run in terminal</source>
-        <translation>Uçbirimde çalıştır</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="115"/>
-        <source>Hide</source>
-        <translation>Gizle</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="125"/>
-        <source>Notify startup</source>
-        <translation>Başlangıçta bildir</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="148"/>
-        <source>Quick Editor</source>
-        <translation>Çabuk düzenleyici</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="160"/>
-        <source>Comment:</source>
-        <translation>Yorum:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="170"/>
-        <source>Restore original item</source>
-        <translation>Özgün öğeyi geri yükle</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="181"/>
-        <source>Command:</source>
-        <translation>Komut:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="191"/>
-        <source>...</source>
-        <translation>...</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="205"/>
-        <source>Name:</source>
-        <translation>Ad:</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="226"/>
-        <source>Icon</source>
-        <translation>Simge</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="266"/>
-        <location filename="../mxmenueditor.cpp" line="541"/>
-        <source>Change icon</source>
-        <translation>Simgeyi değiştir</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="280"/>
-        <source>Categories</source>
-        <translation>Kategoriler</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="292"/>
-        <source>Add</source>
-        <translation>Ekle</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="306"/>
-        <source>Delete</source>
-        <translation>Sil</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="372"/>
-        <source>Quit application</source>
-        <translation>Uygulamadan çık</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="375"/>
-        <source>Close</source>
-        <translation>Kapat</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="382"/>
-        <source>Alt+N</source>
-        <translation>Alt+N</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="423"/>
-        <source>Display help</source>
-        <translation>Yardımı görüntüle</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="426"/>
-        <source>Help</source>
-        <translation>Yardım</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="433"/>
-        <source>Alt+H</source>
-        <translation>Alt+H</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="452"/>
-        <source>Save Changes</source>
-        <translation>Değişiklikleri kaydet</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="459"/>
-        <source>Ctrl+S</source>
-        <translation>Ctrl+S</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="494"/>
-        <source>About this application</source>
-        <translation>Uygulama hakkında</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="497"/>
-        <source>About...</source>
-        <translation>Hakkında...</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.ui" line="504"/>
-        <source>Alt+B</source>
-        <translation>Alt+B</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="462"/>
-        <source>Select executable file</source>
-        <translation>Çalıştırılabilir dosyayı seçin</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="525"/>
-        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
-        <translation>Resim Dosyaları  (*.png *.jpg *.bmp *.xpm)</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="718"/>
-        <source>Choose category</source>
-        <translation>Kategori seçin</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="729"/>
-        <location filename="../mxmenueditor.cpp" line="845"/>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Cancel</source>
-        <translation>İptal</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="730"/>
-        <source>OK</source>
-        <translation>Tamam</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="820"/>
-        <source>Error</source>
-        <translation>Hata</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="820"/>
-        <source>Could not save the file</source>
-        <translation>Dosya kaydedilemedi</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="838"/>
-        <source>About MX Menu Editor</source>
-        <translation>MX Menü Düzenleyici Hakkında</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="839"/>
-        <source>Version: </source>
-        <translation>Sürüm</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="840"/>
-        <source>Program for editing Xfce menu</source>
-        <translation>Xfce menüsünü düzenleme programı</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="842"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation>Copyright (c) MX Linux</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="843"/>
-        <source>License</source>
-        <translation>Ruhsat</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="844"/>
-        <source>Changelog</source>
-        <translation>Değişim günlüğü</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="860"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Kapat</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Save changes?</source>
-        <translation>Değişiklikler kaydedilsin mi?</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Do you want to save your edits?</source>
-        <translation>Düzenlemelerinizi kaydetmek istiyor musunuz?</translation>
-    </message>
-    <message>
-        <location filename="../mxmenueditor.cpp" line="906"/>
-        <source>Save</source>
-        <translation>Kaydet</translation>
-    </message>
-</context>
 </TS>
